==> neper-1.9.0.tgz: neper-1.9.0/src/neut/neut_geo/neut_geo0.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2010, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#ifndef NEUT_GEO0_H
#define NEUT_GEO0_H

#include"../neut_structs.h"

extern void neut_geo_set_zero (struct GEO *);
extern struct GEO neut_geo_alloc (int, int, int, int);
extern void neut_geo_free (struct GEO*);
extern int neut_geo_face_bound (struct GEO, int);
extern void neut_geo_poly_ver (struct GEO, int, int*);
extern void neut_geo_poly_edge (struct GEO, int, int*);
extern void neut_geo_edge_poly (struct GEO, int, int*);
extern void neut_geo_ver_face (struct GEO, int, int*);
extern void neut_geo_ver_poly (struct GEO, int, int*);

extern int neut_geo_poly_true (struct GEO, int);
extern int neut_geo_edge_true (struct GEO, int*, int);
extern int neut_geo_face_true (struct GEO, int*, int);
extern int neut_geo_ver_true (struct GEO, int*, int);
extern int neut_geo_poly_body (struct GEO, int);
extern int neut_geo_ver_polytruelevelmax (struct GEO, int*, int);
extern int neut_geo_ver_polybodylevelmax (struct GEO, int*, int);
extern int neut_geo_edge_polytruelevelmax (struct GEO, int*, int);
extern int neut_geo_edge_polybodylevelmax (struct GEO, int*, int);
extern int neut_geo_face_polybodylevelmax (struct GEO, int);

extern int neut_geo_edge_centre (struct GEO, int, double*);

extern void neut_geo_init_polytrue (struct GEO*);
extern void neut_geo_init_polybody (struct GEO*);
extern void neut_geo_del_polytrue (struct GEO*);

extern void neut_geo_fod (struct GEO, int***);
extern int neut_geo_ver_apolytrue2 (struct GEO, int*, int);

extern int neut_geo_edge_selratio (struct GEO, struct GEOPARA, int, double*);

extern int neut_geo_face_area (struct GEO, int, double*);
extern int neut_geo_volume (struct GEO, double*);
extern int neut_geo_poly_volume (struct GEO, int, double*);

extern void neut_geo_init_edgelength (struct GEO*);
extern void neut_geo_edge_length (struct GEO*, int);

extern void neut_geo_polys_skinfaces (struct GEO, int*, int, int**, int**, int*);

extern void neut_geo_init_polystuff_fromfacepoly (struct GEO*);
extern void neut_geo_init_edgestuff_fromver (struct GEO*);
extern void neut_geo_init_facestuff_fromedge (struct GEO*);
extern void neut_geo_init_facestuff_fromver (struct GEO*);
extern void neut_geo_init_boundingbox (struct GEO*);
extern void neut_geo_boundingbox (struct GEO, double**);

extern double neut_geo_face_init_ff (struct GEO*, int);

extern void neut_geo_poly_switch (struct GEO*, int, int);

extern void neut_geo_face_centre (struct GEO, int, double*);

extern void neut_geo_centre (struct GEO, double*);
extern void neut_geo_poly_neighpoly (struct GEO, int, int*, int*);

extern void neut_geo_poly_edge_face (struct GEO, int, int, int*);
extern void neut_geo_poly_face_ori (struct GEO, int, int, int*);
extern void neut_geo_face_edge_ori (struct GEO, int, int, int*);

extern int neut_geo_expr_polytab (struct GEO, char*, int*);
extern int neut_geo_expr_facetab (struct GEO, char*, int*);

#include "neut_geo_geo/neut_geo_geo0.h"
#include "neut_geo_compress/neut_geo_compress0.h"
#include "neut_geo_fprintf/neut_geo_fprintf0.h"
#include "neut_geo_fscanf/neut_geo_fscanf0.h"
#include "neut_geo_scale/neut_geo_scale0.h"
#include "neut_geo_test/neut_geo_test0.h"

#endif /* NEUT_GEO0_H */

==> neper-1.9.2.tgz: neper-1.9.2/src/neut/neut_geo/neut_geo0.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2011, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#ifndef NEUT_GEO0_H
#define NEUT_GEO0_H

#include"../neut_structs.h"

extern void neut_geo_set_zero (struct GEO *);
extern struct GEO neut_geo_alloc (int, int, int, int);
extern void neut_geo_free (struct GEO*);
extern int  neut_geo_face_bound (struct GEO, int);
extern void neut_geo_poly_ver (struct GEO, int, int*);
extern void neut_geo_poly_edge (struct GEO, int, int*);
extern void neut_geo_edge_poly (struct GEO, int, int*);
extern void neut_geo_ver_face (struct GEO, int, int*);
extern void neut_geo_ver_poly (struct GEO, int, int*);

extern int neut_geo_poly_true (struct GEO, int);
extern int neut_geo_edge_true (struct GEO, int*, int);
extern int neut_geo_face_true (struct GEO, int*, int);
extern int neut_geo_ver_true (struct GEO, int*, int);
extern int neut_geo_poly_body (struct GEO, int);
extern int neut_geo_ver_polytruelevelmax (struct GEO, int*, int);
extern int neut_geo_ver_polybodylevelmax (struct GEO, int*, int);
extern int neut_geo_edge_polytruelevelmax (struct GEO, int*, int);
extern int neut_geo_edge_polybodylevelmax (struct GEO, int*, int);
extern int neut_geo_face_polybodylevelmax (struct GEO, int);

extern int neut_geo_edge_centre (struct GEO, int, double*);

extern void neut_geo_init_polytrue (struct GEO*);
extern void neut_geo_init_polybody (struct GEO*);
extern void neut_geo_del_polytrue (struct GEO*);

extern void neut_geo_fod (struct GEO, int***);
extern int neut_geo_ver_apolytrue2 (struct GEO, int*, int);

extern int neut_geo_edge_selratio (struct GEO, struct GEOPARA, int, double*);

extern int neut_geo_face_area (struct GEO, int, double*);
extern int neut_geo_volume (struct GEO, double*);
extern int neut_geo_poly_volume (struct GEO, int, double*);

extern void neut_geo_init_edgelength (struct GEO*);
extern void neut_geo_edge_length (struct GEO*, int);

extern void neut_geo_polys_skinfaces (struct GEO, int*, int, int**, int**, int*);

extern void neut_geo_init_polystuff_fromfacepoly (struct GEO*);
extern void neut_geo_init_edgestuff_fromver (struct GEO*);
extern void neut_geo_init_facestuff_fromedge (struct GEO*);
extern void neut_geo_init_facestuff_fromver (struct GEO*);
extern void neut_geo_init_boundingbox (struct GEO*);
extern void neut_geo_boundingbox (struct GEO, double**);

extern double neut_geo_face_init_ff (struct GEO*, int);

extern void neut_geo_poly_switch (struct GEO*, int, int);

extern void neut_geo_face_centre (struct GEO, int, double*);

extern void neut_geo_centre (struct GEO, double*);
extern void neut_geo_poly_neighpoly (struct GEO, int, int*, int*);

extern void neut_geo_poly_edge_face (struct GEO, int, int, int*);
extern void neut_geo_poly_face_ori (struct GEO, int, int, int*);
extern void neut_geo_face_edge_ori (struct GEO, int, int, int*);

extern int neut_geo_expr_polytab (struct GEO, char*, int*);
extern int neut_geo_expr_facetab (struct GEO, char*, int*);

extern int neut_geo_point_inpoly (struct GEO, double*, int);

extern int neut_geo_face_interpolmesh (struct GEO, int, struct NODES*, struct MESH*);

extern int neut_geo_poly_std (struct GEO, int);
extern int neut_geo_poly_reg (struct GEO, int);

#include "neut_geo_geo/neut_geo_geo0.h"
#include "neut_geo_compress/neut_geo_compress0.h"
#include "neut_geo_fprintf/neut_geo_fprintf0.h"
#include "neut_geo_fscanf/neut_geo_fscanf0.h"
#include "neut_geo_scale/neut_geo_scale0.h"
#include "neut_geo_test/neut_geo_test0.h"

#endif /* NEUT_GEO0_H */
